==> django-jython-1.7.0b2.tar.gz: django-jython-1.7.0b2/doj/tests/settings.py <==
# -*- coding: utf-8 -*-
"""
Django settings for tests project.

For more information on this file, see
https://docs.djangoproject.com/en/dev/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/dev/ref/settings/
"""

# Build paths inside the project like this: os.path.join(BASE_DIR, ...)
import os
BASE_DIR = os.path.dirname(__file__)


# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/dev/howto/deployment/checklist/

# SECURITY WARNING: keep the secret key used in production secret!
SECRET_KEY = 'rebtxok1^7rs-8t7b8idshbe5wc#=nv)%nm-n+1b0c!mdxlrb_'

# SECURITY WARNING: don't run with debug turned on in production!
DEBUG = True

TEMPLATE_DEBUG = True

ALLOWED_HOSTS = []


# Application definition

INSTALLED_APPS = (
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'doj',
    'doj.tests.db',
)

MIDDLEWARE_CLASSES = (
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.auth.middleware.SessionAuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
)

ROOT_URLCONF = 'doj.tests.urls'

WSGI_APPLICATION = 'doj.tests.wsgi.application'


# Database
# https://docs.djangoproject.com/en/dev/ref/settings/#databases

TEST_DATABASES = {
    'sqlite': {
        'ENGINE': 'doj.db.backends.sqlite',
        'NAME': os.path.join(BASE_DIR, 'doj.sqlite3'),
        'TEST_NAME': os.path.join(BASE_DIR, 'doj-tests.sqlite3'),
    },
    'postgresql': {
        'ENGINE': 'doj.db.backends.postgresql',
        'NAME': 'doj',
        'TEST_NAME': 'doj-tests',
        'HOST': 'localhost',
        'USER': 'root',
        'PASSWORD': 'root',
    },
    'mysql': {
        'ENGINE': 'doj.db.backends.mysql',
        'NAME': 'doj',
        'TEST_NAME': 'doj-tests',
        'HOST': 'localhost',
        'USER': 'root',
        'PASSWORD': 'root',
    },
    'mssql': {
        'ENGINE': 'doj.db.backends.mssql',
        'NAME': 'doj',
        'TEST_NAME': 'doj-tests',
        'HOST': 'localhost',
        'USER': 'root',
        'PASSWORD': 'root',
    },
}

DATABASES = {
    'default': TEST_DATABASES['sqlite'],
}

# Internationalization
# https://docs.djangoproject.com/en/dev/topics/i18n/

LANGUAGE_CODE = 'en-gb'

TIME_ZONE = 'UTC'

USE_I18N = True

USE_L10N = True

USE_TZ = True


# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/dev/howto/static-files/

STATIC_URL = '/static/'

==> django-jython-1.8.0b1.tar.gz: django-jython-1.8.0b1/doj/tests/settings.py <==
# -*- coding: utf-8 -*-
"""
Django settings for tests project.

For more information on this file, see
https://docs.djangoproject.com/en/dev/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/dev/ref/settings/
"""

# Build paths inside the project like this: os.path.join(BASE_DIR, ...)
import os
BASE_DIR = os.path.dirname(__file__)


# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/dev/howto/deployment/checklist/

# SECURITY WARNING: keep the secret key used in production secret!
SECRET_KEY = 'rebtxok1^7rs-8t7b8idshbe5wc#=nv)%nm-n+1b0c!mdxlrb_'

# SECURITY WARNING: don't run with debug turned on in production!
DEBUG = True

TEMPLATE_DEBUG = DEBUG

ALLOWED_HOSTS = ['*']


# Application definition

INSTALLED_APPS = (
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'doj',
    'doj.tests.db',
)

MIDDLEWARE_CLASSES = (
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.auth.middleware.SessionAuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
)

ROOT_URLCONF = 'doj.tests.urls'

WSGI_APPLICATION = 'doj.tests.wsgi.application'


# Database
# https://docs.djangoproject.com/en/dev/ref/settings/#databases

TEST_DATABASES = {
    'sqlite': {
        'ENGINE': 'doj.db.backends.sqlite',
        'NAME': os.path.join(BASE_DIR, 'doj.sqlite3'),
        'TEST': {
            'NAME': os.path.join(BASE_DIR, 'doj-tests.sqlite3'),
        }
    },
    'postgresql': {
        'ENGINE': 'doj.db.backends.postgresql',
        'NAME': 'doj',
        'HOST': 'localhost',
        'USER': 'root',
        'PASSWORD': 'root',
        'TEST': {
            'NAME': 'doj-tests',
        }
    },
    'mysql': {
        'ENGINE': 'doj.db.backends.mysql',
        'NAME': 'doj',
        'HOST': 'localhost',
        'USER': 'root',
        'PASSWORD': 'root',
        'TEST': {
            'NAME': 'doj-tests',
        }
    },
    'mssql': {
        'ENGINE': 'doj.db.backends.mssql',
        'NAME': 'doj',
        'HOST': 'localhost',
        'USER': 'root',
        'PASSWORD': 'root',
        'TEST': {
            'NAME': 'doj-tests',
        }
    },
}

DATABASES = {
    'default': TEST_DATABASES['sqlite'],
}

# Internationalization
# https://docs.djangoproject.com/en/dev/topics/i18n/

LANGUAGE_CODE = 'en-gb'

TIME_ZONE = 'UTC'

USE_I18N = True

USE_L10N = True

USE_TZ = True


# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/dev/howto/static-files/

STATIC_URL = '/static/'
